package net.sf.doolin.gui.action;

import net.sf.doolin.util.Utils;

import org.springframework.beans.factory.annotation.Required;

/**
 * Calls a method on the model.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class MethodGUIAction extends AbstractSimpleGUIAction {
	private String propertyPath = "this";
	private String methodName;
	private boolean useContext;

	@Override
	protected void doExecute(ActionContext context) throws Exception {
		Object target = Utils.getProperty(getActionContextData(context),
				this.propertyPath);
		if (this.useContext) {
			// Context bean
			Object o = context.getContext();
			// Calls the method
			Utils.callMethod(target, this.methodName, o);
		} else {
			// Calls the method
			Utils.callMethod(target, this.methodName);
		}
	}

	/**
	 * Sets the name of the method to call on the target bean. This method must
	 * have no parameter.
	 * 
	 * @param methodName
	 *            Method name
	 */
	@Required
	public void setMethodName(String methodName) {
		this.methodName = methodName;
	}

	/**
	 * Sets the path to the property of the target object to call the method on.
	 * It is set to <code>this</code> by default.
	 * 
	 * @param propertyPath
	 *            Property path
	 */
	public void setPropertyPath(String propertyPath) {
		this.propertyPath = propertyPath;
	}

	/**
	 * Sets if the action contextual data must be used as a parameter to the
	 * method call.
	 * 
	 * @param useContext
	 *            <code>true</code> if the contextual data must be used as a
	 *            parameter for the method call.
	 */
	public void setUseContext(boolean useContext) {
		this.useContext = useContext;
	}

}
