package net.sf.doolin.gui.action.path;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.action.path.item.ActionPath;
import net.sf.doolin.gui.action.path.list.ActionPathList;
import net.sf.doolin.gui.util.PropertyContainer;

/**
 * Menu bar and its context.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class ActionBarContext implements PropertyContainer {

	private final ActionContext actionContext;
	private final ActionPathList actionPaths;

	private final Map<Object, Object> properties = new HashMap<Object, Object>();

	/**
	 * Instantiates a new menu bar context.
	 * 
	 * @param actionPaths
	 *            List of action paths
	 * @param actionContext
	 *            the action context
	 */
	public ActionBarContext(ActionPathList actionPaths,
			ActionContext actionContext) {
		this.actionPaths = actionPaths;
		this.actionContext = actionContext;
	}

	/**
	 * Gets the action context.
	 * 
	 * @return the action context
	 */
	public ActionContext getActionContext() {
		return this.actionContext;
	}

	/**
	 * Gets the action paths.
	 * 
	 * @return the action paths
	 */
	public ActionPathList getActionPaths() {
		return this.actionPaths;
	}

	/**
	 * Properties associated with this context
	 * 
	 * @return Properties
	 */
	public Map<Object, Object> getProperties() {
		return this.properties;
	}

	@Override
	public Object getProperty(Object key) {
		return this.properties.get(key);
	}

	/**
	 * @return <code>true</code> if the action bar contains no action
	 */
	public boolean isEmpty() {
		List<ActionPath> paths = getActionPaths().getPaths();
		return paths == null || paths.isEmpty();
	}

	@Override
	public void setProperty(Object key, Object value) {
		this.properties.put(key, value);
	}

}