package net.sf.doolin.gui.action.support;

import net.sf.doolin.gui.action.ActionContext;

import org.springframework.beans.factory.annotation.Required;

import com.google.common.base.Function;

/**
 * Delegates that operates a transformation on the parameter before delegating
 * to another delegate.
 * 
 * @author Damien Coraboeuf (x74639)
 * 
 * @param <S>
 *            Type of the source parameter
 * @param <T>
 *            Type of the target parameter
 */
public class ConverterDelegate<S, T> implements ActionDelegate<S> {

	private Function<S, T> converter;
	private ActionDelegate<T> delegate;

	@Override
	public void call(ActionContext actionContext, S parameter) {
		// Transforms
		T targetParameter = this.converter.apply(parameter);
		// Calls
		this.delegate.call(actionContext, targetParameter);
	}

	/**
	 * Gets the converter.
	 * 
	 * @return the converter
	 */
	public Function<S, T> getConverter() {
		return this.converter;
	}

	/**
	 * Gets the delegate.
	 * 
	 * @return the delegate
	 */
	public ActionDelegate<T> getDelegate() {
		return this.delegate;
	}

	/**
	 * Sets the converter.
	 * 
	 * @param converter
	 *            the converter
	 */
	@Required
	public void setConverter(Function<S, T> converter) {
		this.converter = converter;
	}

	/**
	 * Sets the delegate to call after conversion.
	 * 
	 * @param delegate
	 *            the new delegate
	 */
	@Required
	public void setDelegate(ActionDelegate<T> delegate) {
		this.delegate = delegate;
	}

}
