package net.sf.doolin.gui.action.support;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.util.factory.DataFactory;

import com.google.common.base.Function;

/**
 * Converts an action context to another by getting a property of the original
 * action context data.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class DataActionContextConverter implements
		Function<ActionContext, ActionContext> {

	private DataFactory<?> dataFactory;

	@Override
	public ActionContext apply(ActionContext source) {
		// Source data
		Object sourceData = source.getData();
		// Conversion
		Object newData = this.dataFactory.create(sourceData);
		// Creates the new context
		return new DelegateDataActionContext(source, newData);
	}

	/**
	 * Gets the factory for the action context data
	 * 
	 * @return Factory
	 */
	public DataFactory<?> getDataFactory() {
		return this.dataFactory;
	}

	/**
	 * Sets the factory for the action context data
	 * 
	 * @param dataFactory
	 *            Factory
	 */
	public void setDataFactory(DataFactory<?> dataFactory) {
		this.dataFactory = dataFactory;
	}

}
