package net.sf.doolin.gui.action.support;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.util.Utils;

import org.springframework.beans.factory.annotation.Required;

/**
 * Delegates the call to a method on the model.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <E>
 *            Type of the parameter
 */
public class MethodActionDelegate<E> implements ActionDelegate<E> {

	private String propertyPath = "";
	private String methodName;

	@Override
	public void call(ActionContext actionContext, E parameter) {
		// Gets the target
		Object target = Utils.getProperty(actionContext.getData(),
				this.propertyPath);
		// Calls the method
		Utils.callMethod(target, this.methodName, parameter);
	}

	/**
	 * Sets the path to the property of the context data to call the method on.
	 * 
	 * @param propertyPath
	 *            Property path
	 */
	public void setPropertyPath(String propertyPath) {
		this.propertyPath = propertyPath;
	}

	/**
	 * Sets the name of the method to call
	 * 
	 * @param methodName
	 *            Method name
	 */
	@Required
	public void setMethodName(String methodName) {
		this.methodName = methodName;
	}

}
