package net.sf.doolin.gui.action.support;

import java.awt.event.ActionEvent;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.action.GUIAction;
import net.sf.doolin.gui.display.DisplayStateHandler;
import net.sf.doolin.gui.expression.GUIExpression;
import net.sf.doolin.gui.service.IconSize;

/**
 * Simple action for a {@link GUIAction}.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class SwingAction extends AbstractSwingAction {

	private static final long serialVersionUID = 1L;

	/**
	 * Action key that stores the ID of the action.
	 */
	public static final String ID_KEY = "SwingActionId";

	private final GUIAction action;
	private final ActionContext actionContext;

	/**
	 * Constructor.
	 * 
	 * @param actionContext
	 *            Action content
	 * @param action
	 *            Action to execute
	 * @param iconSize
	 *            Desired size for the icon
	 */
	public SwingAction(ActionContext actionContext, GUIAction action,
			final IconSize iconSize) {
		this.action = action;
		this.actionContext = actionContext;
		// ID
		putValue(ID_KEY, action.getId());
		// Text
		GUIExpression textExpression = action.getTextExpression(actionContext);
		if (textExpression != null) {
			setText(textExpression.getValue());
			textExpression.connect(actionContext.getSubscriberValidator(),
					this, "text");
		}
		// Icon
		final GUIExpression iconIDExpression = action
				.getIconIDExpression(actionContext);
		if (iconIDExpression != null) {
			setIcon(action.getIcon(iconIDExpression.getValue(), iconSize));
			iconIDExpression.subscribe(actionContext.getSubscriberValidator(),
					new Runnable() {

						@Override
						public void run() {
							setIcon(SwingAction.this.action.getIcon(
									iconIDExpression.getValue(), iconSize));
						}
					});
		}
		// Shortcut
		GUIExpression shortcutExpression = action
				.getShortcutExpression(actionContext);
		if (shortcutExpression != null) {
			setShortcut(shortcutExpression.getValue());
			shortcutExpression.connect(actionContext.getSubscriberValidator(),
					this, "shortcut");
		}
		// Tip
		GUIExpression tipExpression = action.getTipExpression(actionContext);
		if (tipExpression != null) {
			setTip(tipExpression.getValue());
			tipExpression.connect(actionContext.getSubscriberValidator(), this,
					"tip");
		}
		// Display state
		DisplayStateHandler handler = action.getDisplayStateHandler();
		if (handler != null) {
			handler.connect(actionContext, this, "state");
		}
	}

	/**
	 * Delegates to {@link GUIAction#execute(ActionContext)}.
	 */
	@Override
	public void actionPerformed(ActionEvent e) {
		this.action.execute(this.actionContext);
	}

	@Override
	public String toString() {
		return this.action.toString();
	}

}
