package net.sf.doolin.gui.action.swing;

import javax.swing.Action;
import javax.swing.JMenu;
import javax.swing.JMenuItem;

import net.sf.doolin.bus.Bus;
import net.sf.doolin.bus.SubscriberValidator;
import net.sf.doolin.bus.support.PropertyChangeSupport;
import net.sf.doolin.gui.action.support.AbstractSwingAction;
import net.sf.doolin.gui.swing.MnemonicInfo;

/**
 * Base implementation for the build of a {@link JMenu}.
 * 
 * @author Damien Coraboeuf
 * 
 */
public abstract class AbstractJMenuBuilder extends AbstractMenuBuilder {

	/**
	 * Creates a {@link JMenu} with the given name and label.
	 * 
	 * @param name
	 *            Identifier for the {@link JMenu}
	 * @param label
	 *            Label for the {@link JMenu}
	 * @return Configured menu
	 * @see MnemonicInfo#configureButton(javax.swing.AbstractButton)
	 */
	protected JMenu createMenu(String name, String label) {
		JMenu menu = new JMenu();
		MnemonicInfo info = new MnemonicInfo(label);
		info.configureButton(menu);
		menu.setName(name);
		return menu;
	}

	/**
	 * Creates a {@link JMenuItem}. The visibility of the menu item is bound to
	 * the visibility property of the
	 * {@link net.sf.doolin.gui.action.support.SwingAction}.
	 * 
	 * @param subscriberValidator
	 *            Validator for the subscription on the {@link Bus}	 *
	 * @param swingAction
	 *            Action to associate with the menu item
	 * @return Menu item
	 */
	protected JMenuItem createMenuItem(SubscriberValidator subscriberValidator,
			Action swingAction) {
		// Menu item
		JMenuItem menuItem = new JMenuItem(swingAction);
		// Connects the visibility
		PropertyChangeSupport.connectOneWayAndUpdate(subscriberValidator,
				swingAction, AbstractSwingAction.VISIBLE_PROPERTY, menuItem,
				"visible");
		// OK
		return menuItem;
	}
}
