package net.sf.doolin.gui.action.swing;

import javax.swing.Action;
import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.JToolBar;

import net.sf.doolin.bus.SubscriberValidator;
import net.sf.doolin.bus.support.PropertyChangeSupport;
import net.sf.doolin.gui.action.support.AbstractSwingAction;

/**
 * Tool bar builder
 * 
 * @author Damien Coraboeuf
 * 
 */
public class JToolBarBuilder extends AbstractMenuBuilder {

	private final JToolBar toolBar;

	/**
	 * Constructor.
	 * 
	 * @param toolBar
	 *            Tool bar to build
	 */
	public JToolBarBuilder(JToolBar toolBar) {
		this.toolBar = toolBar;
	}

	@Override
	protected void createSeparator() {
		this.toolBar.addSeparator();
	}

	@Override
	public void add(JComponent component) {
		this.toolBar.add(component);
	}

	@Override
	public void add(SubscriberValidator subscriberValidator, Action swingAction) {
		// Creates the button
		JButton button = this.toolBar.add(swingAction);
		// Connects the visibility
		PropertyChangeSupport.connectOneWayAndUpdate(subscriberValidator,
				swingAction, AbstractSwingAction.VISIBLE_PROPERTY, button,
				"visible");
	}

	@Override
	public MenuBuilder createSubMenu(String name, String label) {
		// TODO Creates toolbar menu
		throw new RuntimeException("NYI");
	}

	@Override
	public void clear() {
		this.toolBar.removeAll();
	}

}
