package net.sf.doolin.gui.action.task;

import javax.swing.SwingWorker;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.monitor.TaskException;

/**
 * This {@link GUITaskExecutor} executes the task in the background, using a
 * {@link SwingWorker}.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <B>
 *            Type of bean sent to the task
 * @param <R>
 *            Type of bean returned by the task
 */
public class BackgroundGUITaskExecutor<B, R> implements GUITaskExecutor<B, R> {

	@Override
	public void execute(final ActionContext actionContext, final B bean,
			final GUITask<B, R> task) throws TaskException {
		// Swing worker
		SwingWorker<R, Void> worker = new SwingWorker<R, Void>() {

			@Override
			protected R doInBackground() throws Exception {
				return task.doInBackground(actionContext, bean);
			}

			@Override
			protected void done() {
				try {
					R result = get();
					task.doOnResult(actionContext, bean, result);
				} catch (Exception ex) {
					actionContext.getApplication().getInfoService().error(
							actionContext, ex,
							"BackgroundGUITaskExecutor.error", ex);
				}
			}
		};
		// Launches the worker
		worker.execute();
	}

}
