package net.sf.doolin.gui.bus;

import ca.odell.glazedlists.BasicEventList;
import ca.odell.glazedlists.EventList;
import ca.odell.glazedlists.util.concurrent.Lock;
import net.sf.doolin.bus.BusLog;
import net.sf.doolin.bus.Subscriber;
import net.sf.doolin.bus.bean.Bean;

public class BusMonitoringLog extends Bean implements BusLog {

    public static final String LOGGING_LIMIT = "loggingLimit";

    private final BusLog defaultLog;
    private final EventList<BusMonitoringLogEntry> entries = new BasicEventList<BusMonitoringLogEntry>();

    private int loggingLimit = 100;

    public BusMonitoringLog(BusLog defaultLog) {
        this.defaultLog = defaultLog;
    }

    public void clear() {
        Lock lock = this.entries.getReadWriteLock().writeLock();
        lock.lock();
        try {
            this.entries.clear();
        } finally {
            lock.unlock();
        }
    }

    public EventList<BusMonitoringLogEntry> getEntries() {
        return this.entries;
    }

    public int getLoggingLimit() {
        return this.loggingLimit;
    }

    @Override
    public <M> void messageAccepted(M message, Subscriber<M> subscriber) {
        this.defaultLog.messageAccepted(message, subscriber);
        // Logs the message
        Lock lock = this.entries.getReadWriteLock().writeLock();
        lock.lock();
        try {
            this.entries.add(new BusMonitoringLogEntry(message, subscriber));
            if (this.entries.size() > this.loggingLimit) {
                while (this.entries.size() > this.loggingLimit) {
                    this.entries.remove(0);
                }
            }
        } finally {
            lock.unlock();
        }
    }

    @Override
    public void messageNoSubscription(Object message) {
        this.defaultLog.messageNoSubscription(message);
    }

    @Override
    public void messageReceived(Object message) {
        this.defaultLog.messageReceived(message);
    }

    @Override
    public <M> void messageWithError(M message, Subscriber<M> subscriber,
                                     Exception ex) {
        this.defaultLog.messageWithError(message, subscriber, ex);
    }

    @Override
    public void registrationOk(Subscriber<?> subscriber) {
        this.defaultLog.registrationOk(subscriber);
    }

    public void setLoggingLimit(int loggingLimit) {
        notify(LOGGING_LIMIT, this.loggingLimit,
                this.loggingLimit = loggingLimit);
        // Trim list
        Lock lock = this.entries.getReadWriteLock().writeLock();
        lock.lock();
        try {
            if (this.entries.size() > loggingLimit) {
                while (this.entries.size() > loggingLimit) {
                    this.entries.remove(0);
                }
            }
        } finally {
            lock.unlock();
        }

    }

    @Override
    public void unregistration(Subscriber<?> subscriber) {
        this.defaultLog.unregistration(subscriber);
    }

}
