package net.sf.doolin.gui.bus;

import java.awt.Dialog;
import java.awt.Toolkit;
import java.awt.Dialog.ModalExclusionType;

import javax.swing.SwingUtilities;

import net.sf.doolin.gui.window.GUIWindow;
import net.sf.doolin.gui.window.opener.GUIWindowAdapter;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class BusMonitoringWindowListener extends
		GUIWindowAdapter<BusMonitoringModel> {

	private static final Logger logger = LoggerFactory
			.getLogger(BusMonitoringWindowListener.class);

	@Override
	public void onWindowClosed(GUIWindow<BusMonitoringModel> window) {
		Thread taskThread = (Thread) window
				.getProperty(BusMonitoringRefreshTask.class);
		if (taskThread != null && taskThread.isAlive()) {
			taskThread.interrupt();
		}
	}

	@Override
	public void onWindowInit(GUIWindow<BusMonitoringModel> window) {
		BusMonitoringModel model = window.getWindowData();
		// Window won't be blocked by modal windows
		ModalExclusionType modalExclusionType = Dialog.ModalExclusionType.TOOLKIT_EXCLUDE;
		if (Toolkit.getDefaultToolkit().isModalExclusionTypeSupported(
				modalExclusionType)) {
			SwingUtilities.getWindowAncestor(window.getWindowPanel())
					.setModalExclusionType(modalExclusionType);
		} else {
			logger.info(modalExclusionType
					+ " modal exclusion type is not supported");
		}

		// Runs the refresh task
		BusMonitoringRefreshTask task = new BusMonitoringRefreshTask(model);
		Thread taskThread = new Thread(task, "Bus Monitoring Refresh");
		taskThread.setDaemon(true);
		// Stores in the window
		window.setProperty(BusMonitoringRefreshTask.class, taskThread);
		// Starts it
		taskThread.start();
	}

}
