package net.sf.doolin.gui.display;

import net.sf.doolin.util.Adapter;

import org.springframework.beans.factory.annotation.Required;

/**
 * This display state handler is based on a property of the context. This
 * property is adapted to a display state using an adapter.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <S>
 *            Type of the property to convert to a display state
 */
public class AdaptedContextPropertyDisplayStateHandler<S> extends
		AbstractContextPropertyDisplayStateHandler<S> {

	private Adapter<S, DisplayState> adapter;

	/**
	 * Default constructor
	 */
	public AdaptedContextPropertyDisplayStateHandler() {
	}

	/**
	 * Constructor.
	 * 
	 * @param propertyPath
	 *            Path to the property of the context to take into account
	 * @param adapter
	 *            Adapter from the property to the display date
	 */
	public AdaptedContextPropertyDisplayStateHandler(String propertyPath,
			Adapter<S, DisplayState> adapter) {
		super(propertyPath);
		this.adapter = adapter;
	}

	/**
	 * Gets the adapter.
	 * 
	 * @return the adapter
	 */
	public Adapter<S, DisplayState> getAdapter() {
		return this.adapter;
	}

	/**
	 * Sets the adapter.
	 * 
	 * @param adapter
	 *            the adapter
	 */
	@Required
	public void setAdapter(Adapter<S, DisplayState> adapter) {
		this.adapter = adapter;
	}

	@Override
	protected DisplayState getDisplayState(S property) {
		return this.adapter.convertSubjectToTarget(property);
	}

}
