package net.sf.doolin.gui.display;

import javax.swing.JComponent;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.field.Field;

/**
 * Utility methods for dealing with display states.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class DisplayStateHandlerUtils {

	private DisplayStateHandlerUtils() {
	}

	/**
	 * Sets the display state for a {@linkplain Field field}.
	 * 
	 * @param <V>
	 *            Type of the field
	 * @param displayStateHandler
	 *            Display state handler to set
	 * @param field
	 *            Field to set
	 * @param component
	 *            Component for the field (it will receive the state)
	 * @see Field#getFieldDescriptor()
	 * @see net.sf.doolin.gui.field.FieldDescriptor#setDisplayState(Field,
	 *      JComponent, DisplayState)
	 */
	public static <V> void setupField(
			final DisplayStateHandler displayStateHandler,
			final Field<V> field, final JComponent component) {
		final ActionContext fieldActionContext = field.getActionContext();
		Runnable task = new Runnable() {

			@Override
			public void run() {
				DisplayState state = displayStateHandler
						.getDisplayState(fieldActionContext);
				updateField(state, field, component);
			}
		};
		displayStateHandler.subscribe(fieldActionContext, task);
		task.run();
	}

	private static <V> void updateField(DisplayState displayState,
			Field<V> field, JComponent component) {
		field.getFieldDescriptor().setDisplayState(field, component,
				displayState);
	}

}
