package net.sf.doolin.gui.field;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JCheckBox;

import net.sf.doolin.gui.expression.GUIExpression;
import net.sf.doolin.gui.field.support.SimpleField;
import net.sf.doolin.gui.view.GUIView;

/**
 * {@link JCheckBox} field descriptor.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <V>
 *            Type of object for the view
 */
public class FieldCheck<V> extends AbstractPropertyFieldDescriptor<V> {

	private static final long serialVersionUID = 1L;

	private String text = "";

	/**
	 * {@inheritDoc}.
	 * 
	 * @param view
	 *            the view
	 * 
	 * @return the field< v>
	 */
	@Override
	public Field<V> createField(final GUIView<V> view) {

		// Creates the check-box
		final JCheckBox c = new JCheckBox();

		// Text expression
		final GUIExpression textExpression = new GUIExpression(view
				.getActionContext().getSubscriberValidator(), view
				.getViewData(), this.text);
		textExpression.connect(
				view.getActionContext().getSubscriberValidator(), c, "text");

		// Component -> Model
		c.addActionListener(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent e) {
				Object value = c.isSelected();
				setProperty(view, value);
			}
		});

		// Model -> Component
		subscribe(view, c, "selected");

		// OK
		return new SimpleField<V>(view, this, c);
	}

	/**
	 * Gets the text.
	 * 
	 * @return the text
	 */
	public String getText() {
		return this.text;
	}

	/**
	 * Sets the text.
	 * 
	 * @param text
	 *            the new text
	 */
	public void setText(String text) {
		this.text = text;
	}

}
