package net.sf.doolin.gui.field;

import javax.swing.JLabel;
import javax.swing.SwingUtilities;

import net.sf.doolin.gui.field.support.SimpleField;
import net.sf.doolin.gui.swing.DefaultLabelInfoProvider;
import net.sf.doolin.gui.swing.LabelInfo;
import net.sf.doolin.gui.swing.LabelInfoProvider;
import net.sf.doolin.gui.view.GUIView;

/**
 * {@link JLabel} field descriptor based on a
 * {@link net.sf.doolin.gui.swing.LabelInfoProvider}.
 * 
 * @param <V>
 *            Type of object for the view
 */
public class FieldLabelInfo<V> extends AbstractPropertyFieldDescriptor<V> {

	private static final long serialVersionUID = 1L;

	private LabelInfoProvider labelInfoProvider = new DefaultLabelInfoProvider();

	@Override
	public Field<V> createField(final GUIView<V> view) {
		// Creates the label
		final JLabel label = new JLabel();
		// Update task
		Runnable updateTask = new Runnable() {

			@Override
			public void run() {
				// Gets the property
				Object value = getProperty(view);
				// Renders the property
				final LabelInfo labelInfo = FieldLabelInfo.this.labelInfoProvider
						.getLabelIcon(value);
				// Configures the label
				SwingUtilities.invokeLater(new Runnable() {

					@Override
					public void run() {
						label.setText(labelInfo.getText());
						label.setIcon(labelInfo.getIcon());
					}
				});
			}
		};
		// Model -> Label
		subscribe(view, updateTask);
		// Initialisation
		updateTask.run();
		// OK
		return new SimpleField<V>(view, this, label);
	}

	/**
	 * Gets the {@link LabelInfoProvider} used to render this field.
	 * 
	 * @return Label info provider
	 */
	public LabelInfoProvider getLabelInfoProvider() {
		return this.labelInfoProvider;
	}

	/**
	 * Sets the {@link LabelInfoProvider} used to render this field.
	 * 
	 * @param labelInfoProvider
	 *            Label info provider
	 */
	public void setLabelInfoProvider(LabelInfoProvider labelInfoProvider) {
		this.labelInfoProvider = labelInfoProvider;
	}
}
