package net.sf.doolin.gui.field.list.multi;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import javax.swing.AbstractAction;
import javax.swing.JButton;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.JTextField;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;

import net.sf.doolin.gui.action.support.ActionDelegate;
import net.sf.doolin.gui.field.table.renderer.LabelInfoTableCellRenderer;
import net.sf.doolin.gui.swing.DoolinIcons;
import net.sf.doolin.gui.swing.SwingUtils;
import net.sf.doolin.util.collection.ListUtils;
import net.sf.doolin.util.unit.Unit;
import net.sf.doolin.util.unit.ValueUnit;

import org.apache.commons.lang.StringUtils;

import ca.odell.glazedlists.EventList;
import ca.odell.glazedlists.FunctionList;
import ca.odell.glazedlists.gui.TableFormat;
import ca.odell.glazedlists.swing.EventTableModel;
import ca.odell.glazedlists.util.concurrent.Lock;

import com.jgoodies.forms.layout.CellConstraints;
import com.jgoodies.forms.layout.FormLayout;

public class MultiComboComponent<V, E> extends JPanel {

	private static final long serialVersionUID = 1L;

	private static class Item2SelectableFunction<E> implements
			FunctionList.Function<E, SelectableItem<E>> {

		private final EventList<E> selectionList;

		private Item2SelectableFunction(EventList<E> selectionList) {
			this.selectionList = selectionList;
		}

		@Override
		public SelectableItem<E> evaluate(E item) {
			boolean selected = this.selectionList.contains(item);
			return new SelectableItem<E>(item, selected);
		}
	}

	private static class Selectable2ItemFunction<E> implements
			FunctionList.Function<SelectableItem<E>, E> {
		@Override
		public E evaluate(SelectableItem<E> sourceValue) {
			return sourceValue.getItem();
		}
	}

	private static final Insets BUTTON_MARGIN = new Insets(2, 2, 2, 2);

	private final List<MultiComboListener> listeners = new ArrayList<MultiComboListener>();

	private final MultiComboField<V, E> field;

	private JTable selectableTable;

	public MultiComboComponent(final MultiComboField<V, E> field) {
		this.field = field;

		// Container
		setLayout(new BorderLayout());

		// Descriptor
		FieldMultiCombo<V, E> multiComboDescriptor = field
				.getMultiComboDescriptor();

		// Delete action
		AbstractAction deleteAction = new AbstractAction() {

			private static final long serialVersionUID = 1L;

			@Override
			public void actionPerformed(ActionEvent e) {
				doDelete();
			}
		};

		// Source list
		final EventList<E> sourceList = field.getSourceList();
		final EventList<E> selectionList = field.getSelectionList();

		// TODO Filter on the name

		// Selection list
		EventList<SelectableItem<E>> selectableList = new FunctionList<E, SelectableItem<E>>(
				sourceList, new Item2SelectableFunction<E>(selectionList),
				new Selectable2ItemFunction<E>());

		// Table format
		TableFormat<SelectableItem<E>> selectableTableFormat = new MultiComboTableFormat<V, E>(
				field);

		// Table model
		EventTableModel<SelectableItem<E>> selectableTableModel = new EventTableModel<SelectableItem<E>>(
				selectableList, selectableTableFormat);

		// Table
		this.selectableTable = new JTable(selectableTableModel);

		// TODO Delete key on the table
		// TODO Disable the delete if no item is selected

		// No header for the table
		this.selectableTable.setTableHeader(null);

		// Column width
		SwingUtils.setTableColumnWidth(this.selectableTable,
				MultiComboTableFormat.COL_SELECTED, new ValueUnit(24,
						Unit.PIXEL), false);

		// Renderer
		this.selectableTable.getColumnModel().getColumn(
				MultiComboTableFormat.COL_ITEM).setCellRenderer(
				new LabelInfoTableCellRenderer(multiComboDescriptor
						.getLabelInfoProvider()));

		// Scroll pane
		JScrollPane scrollPane = new JScrollPane(this.selectableTable);
		scrollPane.setPreferredSize(new Dimension(200, this.selectableTable
				.getRowHeight()
				* multiComboDescriptor.getVisibleRows()));
		add(scrollPane, BorderLayout.CENTER);

		// Button container
		FormLayout buttonLayout = new FormLayout(
				"fill:default:grow,default,default,default", "default");
		CellConstraints cc = new CellConstraints();
		JPanel buttonContainer = new JPanel(buttonLayout);
		add(buttonContainer, BorderLayout.PAGE_END);

		// Creation
		final ActionDelegate<String> creationDelegate = multiComboDescriptor
				.getCreationDelegate();
		if (creationDelegate != null) {
			// Text field
			final JTextField addText = new JTextField(10);
			buttonContainer.add(addText, cc.xy(1, 1));
			// Add button
			final JButton addButton = createButton(DoolinIcons.ADD);
			addButton.addActionListener(new ActionListener() {

				@Override
				public void actionPerformed(ActionEvent e) {
					// Text for the creation
					String text = addText.getText();
					// Does something with it
					creationDelegate.call(field.getActionContext(), text);
					// Clears the text
					addText.setText(null);
				}
			});
			buttonContainer.add(addButton, cc.xy(2, 1));
			// Controls the state of the add button
			addButton.setEnabled(false);
			addText.getDocument().addDocumentListener(new DocumentListener() {

				@Override
				public void changedUpdate(DocumentEvent e) {
					check();
				}

				private void check() {
					boolean containsText = StringUtils.isNotBlank(addText
							.getText());
					addButton.setEnabled(containsText);
				}

				@Override
				public void insertUpdate(DocumentEvent e) {
					check();
				}

				@Override
				public void removeUpdate(DocumentEvent e) {
					check();
				}
			});
		}

		// Close button
		if (multiComboDescriptor.isCanClose()) {
			JButton closeButton = createButton(DoolinIcons.CLOSE);
			closeButton.addActionListener(new ActionListener() {

				@Override
				public void actionPerformed(ActionEvent e) {
					doClose();
				}
			});
			buttonContainer.add(closeButton, cc.xy(3, 1));
		}

		// Delete button
		ActionDelegate<Collection<E>> deleteDelegate = multiComboDescriptor
				.getDeleteDelegate();
		if (deleteDelegate != null) {
			JButton deleteButton = createButton(DoolinIcons.DELETE);
			deleteButton.addActionListener(deleteAction);
			buttonContainer.add(deleteButton, cc.xy(4, 1));
		}
	}

	public synchronized void addMultiComboListener(MultiComboListener listener) {
		this.listeners.add(listener);
	}

	private JButton createButton(String iconID) {
		JButton button = new JButton(DoolinIcons.getIcon(iconID));
		button.setMargin(BUTTON_MARGIN);
		button.setBorder(null);
		return button;
	}

	protected void doClose() {
		List<MultiComboListener> list = new ArrayList<MultiComboListener>(
				this.listeners);
		for (MultiComboListener l : list) {
			l.onClose();
		}
	}

	protected void doDelete() {
		// Gets the delegate
		ActionDelegate<Collection<E>> deleteDelegate = this.field
				.getMultiComboDescriptor().getDeleteDelegate();
		if (deleteDelegate != null) {
			int[] rows = this.selectableTable.getSelectedRows();
			List<E> list = ListUtils.sublist(this.field.getSourceList(), rows);
			deleteDelegate.call(this.field.getActionContext(), list);
			// OK, remove from the source and selection
			remove(this.field.getSelectionList(), list);
			remove(this.field.getSourceList(), list);
		}
	}

	private void remove(EventList<E> eventList, List<E> list) {
		Lock lock = eventList.getReadWriteLock().writeLock();
		lock.lock();
		try {
			eventList.removeAll(list);
		} finally {
			lock.unlock();
		}
	}

	public synchronized void removeMultiComboListener(
			MultiComboListener listener) {
		this.listeners.remove(listener);
	}

}
