package net.sf.doolin.gui.field.list.multi;

import javax.swing.JComponent;

import net.sf.doolin.gui.field.support.SimpleField;
import net.sf.doolin.gui.view.GUIView;
import ca.odell.glazedlists.EventList;
import ca.odell.glazedlists.util.concurrent.Lock;

public class MultiComboField<V, E> extends SimpleField<V> {

	private final FieldMultiCombo<V, E> multiComboDescriptor;
	private final EventList<E> sourceList;
	private final EventList<E> selectionList;

	public MultiComboField(GUIView<V> view,
			FieldMultiCombo<V, E> fieldDescriptor, JComponent fieldComponent,
			EventList<E> sourceList, EventList<E> selectionList) {
		super(view, fieldDescriptor, fieldComponent);
		this.multiComboDescriptor = fieldDescriptor;
		this.sourceList = sourceList;
		this.selectionList = selectionList;
	}

	private void addToSelection(E item) {
		Lock lock = this.selectionList.getReadWriteLock().writeLock();
		lock.lock();
		try {
			this.selectionList.add(item);
		} finally {
			lock.unlock();
		}
	}

	/**
	 * @return the multiComboDescriptor
	 */
	public FieldMultiCombo<V, E> getMultiComboDescriptor() {
		return this.multiComboDescriptor;
	}

	/**
	 * @return the selectionList
	 */
	public EventList<E> getSelectionList() {
		return this.selectionList;
	}

	/**
	 * @return the sourceList
	 */
	public EventList<E> getSourceList() {
		return this.sourceList;
	}

	private void removeFromSelection(E item) {
		Lock lock = this.selectionList.getReadWriteLock().writeLock();
		lock.lock();
		try {
			this.selectionList.remove(item);
		} finally {
			lock.unlock();
		}
	}

	public void select(SelectableItem<E> selectableItem) {
		E item = selectableItem.getItem();
		boolean selected = selectableItem.isSelected();
		if (selected) {
			if (!this.selectionList.contains(item)) {
				addToSelection(item);
			}
		} else {
			if (this.selectionList.contains(item)) {
				removeFromSelection(item);
			}
		}
	}

}
