package net.sf.doolin.gui.field.support;

import java.util.HashMap;
import java.util.Map;

import javax.swing.JComponent;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.field.Field;
import net.sf.doolin.gui.field.FieldDescriptor;
import net.sf.doolin.gui.view.GUIView;

/**
 * Abstract field definition.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <V>
 *            type of object for the view
 */
public abstract class AbstractField<V> implements Field<V> {

	private final GUIView<V> view;
	private final FieldDescriptor<V> fieldDescriptor;
	private final Map<Object, Object> properties;

	private ActionContext actionContext;

	/**
	 * Constructor.
	 * 
	 * @param view
	 *            Owning view
	 * @param fieldDescriptor
	 *            Associated descriptor
	 */
	public AbstractField(GUIView<V> view, FieldDescriptor<V> fieldDescriptor) {
		this.view = view;
		this.fieldDescriptor = fieldDescriptor;
		this.properties = new HashMap<Object, Object>(1);
		this.actionContext = new FieldActionContext<V>(this);
	}

	/**
	 * {@inheritDoc}
	 */
	public ActionContext getActionContext() {
		return this.actionContext;
	}

	@Override
	public JComponent getCoreComponent() {
		return getFieldComponent();
	}

	/**
	 * Gets the field descriptor.
	 * 
	 * @return the field descriptor
	 */
	@Override
	public FieldDescriptor<V> getFieldDescriptor() {
		return this.fieldDescriptor;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public Object getProperty(Object key) {
		return this.properties.get(key);
	}

	/**
	 * Gets the view.
	 * 
	 * @return the view
	 */
	@Override
	public GUIView<V> getView() {
		return this.view;
	}

	/**
	 * Sets the action context.
	 * 
	 * @param actionContext
	 *            the new action context
	 */
	protected void setActionContext(ActionContext actionContext) {
		this.actionContext = actionContext;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public void setProperty(Object key, Object value) {
		if (value != null) {
			this.properties.put(key, value);
		} else {
			this.properties.remove(key);
		}
	}

}
