package net.sf.doolin.gui.field.table.column;

import net.sf.doolin.gui.display.ConditionalOperator;
import net.sf.doolin.gui.field.table.Column;
import net.sf.doolin.util.Utils;

/**
 * {@link ColumnEditable} implementation based on the evaluation of a property
 * of the row object.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <T>
 *            Type of the row
 */
public class PropertyColumnEditable<T> implements ColumnEditable<T> {

	private String propertyPath = "";
	private ConditionalOperator operator = ConditionalOperator.NOT_NULL;
	private Object operand;

	@Override
	public boolean isEditable(Column column, T item) {
		Object value = Utils.getProperty(item, this.propertyPath);
		boolean editable = this.operator.evaluate(value, this.operand);
		return editable;
	}

	/**
	 * Sets the path to the property to evaluate ("this" by default)
	 * 
	 * @param propertyPath
	 *            Path to the property
	 */
	public void setPropertyPath(String propertyPath) {
		this.propertyPath = propertyPath;
	}

	/**
	 * Sets the operator to apply to the property. It is set to
	 * {@link ConditionalOperator#NOT_NULL} by default.
	 * 
	 * @param operator
	 *            Operator
	 */
	public void setOperator(ConditionalOperator operator) {
		this.operator = operator;
	}

	/**
	 * Sets the operand used by the {@link ConditionalOperator}.
	 * 
	 * @param operand
	 *            Operand
	 */
	public void setOperand(Object operand) {
		this.operand = operand;
	}

}
