package net.sf.doolin.gui.field.table.editor;

import net.sf.doolin.gui.field.Field;
import net.sf.doolin.gui.field.list.FieldCombo;
import net.sf.doolin.gui.field.table.support.GUITable;
import net.sf.doolin.gui.view.GUIView;
import net.sf.jstring.LocalizableException;
import org.springframework.beans.factory.annotation.Required;

import javax.swing.*;
import javax.swing.table.TableCellEditor;
import java.awt.*;

/**
 * Table cell editor based on a {@link JComboBox}.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <V>
 *            Type of bean for the view
 * @param <E>
 *            Type of bean for the rows
 */
public class ComboTableCellEditor<V, E> extends AbstractCellEditor implements
		TableCellEditor {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	private FieldCombo<V, E> fieldCombo;

	private JComboBox cbo;

	@Override
	public Object getCellEditorValue() {
		return this.cbo.getSelectedItem();
	}

	/**
	 * Gets the field definition for the combo box
	 * 
	 * @return Field definition
	 */
	public FieldCombo<V, E> getFieldCombo() {
		return this.fieldCombo;
	}

	@Override
	public Component getTableCellEditorComponent(JTable table, Object value,
			boolean isSelected, int row, int column) {
		if (this.cbo == null) {
			init(table);
		}
		this.cbo.setSelectedItem(value);
		return this.cbo;
	}

	/**
	 * Initialises the combo box
	 * 
	 * @param table
	 *            Hosting table (must be a {@link GUITable}).
	 */
	protected void init(JTable table) {
		// Gets the GUI table
		if (table instanceof GUITable<?, ?>) {
			@SuppressWarnings("unchecked")
			GUITable<V, E> guiTable = (GUITable<V, E>) table;
			// Gets the view
			GUIView<V> view = guiTable.getTableField().getView();
			// Creates the field
			Field<V> field = this.fieldCombo.createField(view);
			// Gets the combo-box
			this.cbo = (JComboBox) field.getFieldComponent();
		} else {
			throw new LocalizableException("ComboTableCellEditor.NeedGUITable");
		}
	}

	/**
	 * Sets the field definition for the combo box
	 * 
	 * @param fieldCombo
	 *            Field definition
	 */
	@Required
	public void setFieldCombo(FieldCombo<V, E> fieldCombo) {
		this.fieldCombo = fieldCombo;
	}

}
