/*
 * Created on Jul 25, 2007
 */
package net.sf.doolin.gui.field.table.renderer;

import java.awt.Component;

import javax.swing.JTable;
import javax.swing.table.DefaultTableCellRenderer;

import net.sf.doolin.gui.swing.DefaultLabelInfoProvider;
import net.sf.doolin.gui.swing.LabelInfo;
import net.sf.doolin.gui.swing.LabelInfoProvider;

import org.springframework.beans.factory.annotation.Required;

/**
 * Renderer based on a {@link LabelInfoProvider}.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class LabelInfoTableCellRenderer extends DefaultTableCellRenderer {

	private static final long serialVersionUID = 1L;

	private LabelInfoProvider labelProvider = new DefaultLabelInfoProvider();

	/**
	 * Default constructor
	 */
	public LabelInfoTableCellRenderer() {
	}

	/**
	 * Constructor with a predefined label info provider
	 * 
	 * @param labelProvider
	 *            Provider to use
	 */
	public LabelInfoTableCellRenderer(LabelInfoProvider labelProvider) {
		this.labelProvider = labelProvider;
	}

	/**
	 * Gets the label provider.
	 * 
	 * @return the label provider
	 */
	public LabelInfoProvider getLabelProvider() {
		return this.labelProvider;
	}

	@Override
	public Component getTableCellRendererComponent(JTable table, Object value,
			boolean isSelected, boolean hasFocus, int row, int column) {
		// Get label info
		LabelInfo labelIcon = this.labelProvider.getLabelIcon(value);
		// Text
		String text = labelIcon.getText();
		// OK
		super.getTableCellRendererComponent(table, text, isSelected, hasFocus,
				row, column);
		// Icon
		setIcon(labelIcon.getIcon());
		// OK
		return this;
	}

	/**
	 * Sets the label provider.
	 * 
	 * @param labelProvider
	 *            the new label provider
	 */
	@Required
	public void setLabelProvider(LabelInfoProvider labelProvider) {
		this.labelProvider = labelProvider;
	}

}
