package net.sf.doolin.gui.field.table.support;

import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import javax.swing.JPopupMenu;
import javax.swing.SwingUtilities;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.action.GUIAction;
import net.sf.doolin.gui.action.path.ActionBarContext;
import net.sf.doolin.gui.action.path.list.ActionPathList;
import net.sf.doolin.gui.field.table.FieldTable;

/**
 * Mouse listener for a {@link GUITable}.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <V>
 *            Type of object for the view
 * @param <E>
 *            Type of item in the table
 */
public class GUITableMouseListener<V, E> extends MouseAdapter {

	private final GUITable<V, E> table;

	/**
	 * Constructor
	 * 
	 * @param table
	 *            Associated table
	 */
	public GUITableMouseListener(GUITable<V, E> table) {
		this.table = table;
	}

	/**
	 * On a double click, executes any
	 * {@linkplain FieldTable#getDoubleClickAction() associated action}.
	 */
	@Override
	public void mouseClicked(MouseEvent e) {
		if (SwingUtilities.isLeftMouseButton(e) && e.getClickCount() == 2) {
			// Gets the double click action
			GUIAction action = this.table.getTableField().getTableDescriptor()
					.getDoubleClickAction();
			if (action != null) {
				// Action context
				ActionContext actionContext = this.table.getTableField()
						.getActionContext();
				// Executes the action
				action.execute(actionContext);
			}
		}
	}

	/**
	 * On a pop-up menu trigger, builds a pop-up menu for the current item and
	 * displays it. The content of the pop-up menu is defined by the
	 * {@linkplain FieldTable#getTableMenu()} action group.
	 */
	@Override
	public void mouseReleased(MouseEvent e) {
		if (e.isPopupTrigger()) {
			// Selects the row
			int row = this.table.rowAtPoint(e.getPoint());
			if (row >= 0) {
				this.table.setRowSelectionInterval(row, row);
			} else {
				return;
			}
			// Actions for the table menu
			GUITableField<V, E> tableField = this.table.getTableField();
			FieldTable<V, E> fieldTableDescriptor = tableField
					.getTableDescriptor();
			ActionPathList tableMenu = fieldTableDescriptor.getTableMenu();
			if (tableMenu != null) {
				ActionContext actionContext = tableField.getActionContext();
				// Creates the action group
				ActionBarContext actionBarContext = new ActionBarContext(
						tableMenu, actionContext);
				// Creates the menu for this action group
				JPopupMenu popupMenu = fieldTableDescriptor.getActionFactory()
						.createPopupMenu(actionBarContext);
				// Displays the menu
				popupMenu.show(this.table, e.getX(), e.getY());
			}
		}
	}
}
