package net.sf.doolin.gui.field.table.support;

import java.util.List;

import javax.swing.JComponent;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;

import net.sf.doolin.bus.SubscriberValidator;
import net.sf.doolin.gui.app.GUIApplication;
import net.sf.doolin.gui.field.support.AbstractFieldActionContext;
import net.sf.doolin.gui.view.GUIView;
import net.sf.doolin.gui.view.support.ViewSubscriberValidator;
import net.sf.doolin.gui.window.GUIWindow;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * {@link net.sf.doolin.gui.action.ActionContext} for a table. It defines a
 * <code>context</code> property that can be listened to.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <V>
 *            Type of object for the view
 * @param <E>
 *            Type of item in the table
 */
public class TableActionContext<V, E> extends AbstractFieldActionContext {

	private static final long serialVersionUID = 1L;

	private static final Logger log = LoggerFactory
			.getLogger(TableActionContext.class);

	private final GUITableField<V, E> tableField;

	private final SubscriberValidator subscriberValidator;

	/**
	 * Constructor
	 * 
	 * @param tableField
	 *            Associated table field
	 */
	public TableActionContext(GUITableField<V, E> tableField) {
		this.tableField = tableField;
		init();
		// Subscription
		GUIView<V> view = getView();
		this.subscriberValidator = new ViewSubscriberValidator<V>(view);
	}

	@Override
	public GUIApplication getApplication() {
		return getView().getApplication();
	}

	@Override
	public JComponent getComponent() {
		return this.tableField.getTable();
	}

	@Override
	public Object getData() {
		return getView().getViewData();
	}

	@Override
	public SubscriberValidator getSubscriberValidator() {
		return this.subscriberValidator;
	}

	@SuppressWarnings("unchecked")
	@Override
	public <T> GUIView<T> getView() {
		return (GUIView<T>) this.tableField.getView();
	}

	@SuppressWarnings("unchecked")
	@Override
	public <T> GUIWindow<T> getWindow() {
		return (GUIWindow<T>) getView().getParentWindow();
	}

	/**
	 * Initialisation.
	 */
	protected void init() {
		final GUITable<V, E> table = this.tableField.getTable();
		table.getSelectionModel().addListSelectionListener(
				new ListSelectionListener() {

					@Override
					public void valueChanged(ListSelectionEvent e) {
						if (!e.getValueIsAdjusting()) {
							if (TableActionContext.this.tableField
									.getTableDescriptor().getSelectionMode()
									.isMultiple()) {
								List<E> selectedItems = table
										.getSelectedItems();
								setContext(selectedItems);
							} else {
								E selectedItem = table.getSelectedItem();
								log.debug(String.format(
										"Table selection is %s", selectedItem));
								setContext(selectedItem);
							}
						}
					}

				});
		// Initial value
		setContext(table.getSelectedItem());
	}

	@Override
	public String toString() {
		String name = this.tableField.getTableDescriptor().getName();
		if (StringUtils.isBlank(name)) {
			name = this.tableField.getView().getID();
		}
		return "TableActionContext/" + name;
	}

}
