package net.sf.doolin.gui.field.tree.model;

import org.apache.commons.lang.ObjectUtils;

import com.google.common.base.Predicate;

/**
 * This predicate checks the user object associated with a {@link GUITreeNode}.
 */
public class GUITreeNodeUserObjectPredicate implements Predicate<GUITreeNode> {

	private final Object value;
	private final boolean useIdentity;

	/**
	 * Constructor for the predicate.
	 * 
	 * @param value
	 *            The user object to compare against
	 * @param useIdentity
	 *            <code>true</code> if the comparison is done using identity
	 *            (==), <code>false</code> if the comparison is done using the
	 *            <code>equals</code> method.
	 */
	public GUITreeNodeUserObjectPredicate(Object value, boolean useIdentity) {
		this.value = value;
		this.useIdentity = useIdentity;
	}

	@Override
	public boolean apply(GUITreeNode n) {
		Object u = n.getUserObject();
		if (this.useIdentity) {
			return u == this.value;
		} else {
			return ObjectUtils.equals(u, this.value);
		}
	}

	/**
	 * User object
	 * 
	 * @return User object used for the comparison
	 */
	public Object getValue() {
		return this.value;
	}

	/**
	 * Comparison mode
	 * 
	 * @return <code>true</code> if the comparison is done using identity (==),
	 *         <code>false</code> if the comparison is done using the
	 *         <code>equals</code> method.
	 */
	public boolean isUseIdentity() {
		return this.useIdentity;
	}

}
