package net.sf.doolin.gui.monitor;

import javax.swing.SwingWorker;

/**
 * {@link SwingWorker} that has an access to a listener for the task monitoring.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <T>
 *            the result type returned by this {@code SwingWorker's} {@code
 *            doInBackground} and {@code get} methods
 * @param <V>
 *            the type used for carrying out intermediate results by this
 *            {@code SwingWorker's} {@code publish} and {@code process} methods
 */
public abstract class Task<T, V> extends SwingWorker<T, V> {

	private TaskListener<T, V> listener;

	/**
	 * Posts a message to the task listener, which is used to display a progress
	 * message to the {@link TaskMonitor}.
	 * 
	 * @param note
	 *            Note to display
	 */
	protected void fireTaskNote(String note) {
		if (listener != null) {
			listener.onNoteChanged(this, note);
		}
	}

	/**
	 * Gets the listener
	 * 
	 * @return Listener
	 */
	public TaskListener<T, V> getListener() {
		return listener;
	}

	/**
	 * Sets the listener
	 * 
	 * @param listener
	 *            Listener
	 */
	public void setListener(TaskListener<T, V> listener) {
		this.listener = listener;
	}
}
