package net.sf.doolin.gui.service;

import net.sf.doolin.gui.action.ActionContext;

/**
 * Logger service for the application
 * 
 * @author Damien Coraboeuf
 * 
 */
public interface InfoService {

	/**
	 * Asks a confirmation from the user
	 * 
	 * @param actionContext
	 *            Action context
	 * @param messageKey
	 *            Key of the message
	 * @param messageParameters
	 *            Parameters for the message
	 * @return Result of the confirmation
	 */
	boolean confirm(ActionContext actionContext, Object messageKey,
			Object... messageParameters);

	/**
	 * Asks a three-choices confirmation from the user
	 * 
	 * @param actionContext
	 *            Action context
	 * @param messageKey
	 *            Key of the message
	 * @param messageParameters
	 *            Parameters for the message
	 * @return Result of the confirmation
	 */
	ConfirmResult confirm3(ActionContext actionContext, Object messageKey,
			Object... messageParameters);

	/**
	 * Logs an error
	 * 
	 * @param actionContext
	 *            Action context
	 * @param e
	 *            Error to log
	 * @param messageKey
	 *            Key of the message
	 * @param messageParameters
	 *            Parameters for the message
	 */
	void error(ActionContext actionContext, Throwable e, Object messageKey,
			Object... messageParameters);

	/**
	 * Logs an information message
	 * 
	 * @param actionContext
	 *            Action context
	 * @param messageKey
	 *            Key of the message
	 * @param messageParameters
	 *            Parameters for the message
	 */
	void info(ActionContext actionContext, Object messageKey,
			Object... messageParameters);

	/**
	 * Logs a warning
	 * 
	 * @param actionContext
	 *            Action context
	 * @param e
	 *            Warning to log
	 * @param messageKey
	 *            Key of the message
	 * @param messageParameters
	 *            Parameters for the message
	 */
	void warning(ActionContext actionContext, Throwable e, Object messageKey,
			Object... messageParameters);

}
