/*
 * Created on Sep 10, 2007
 */
package net.sf.doolin.gui.service.icon;

import java.util.HashMap;
import java.util.Map;

import org.springframework.beans.factory.InitializingBean;
import org.springframework.beans.factory.annotation.Required;

/**
 * This icon manager is using a property file that maps the icon ids to a
 * resource path. No size is taken into account.
 * 
 * @author Damien Coraboeuf
 */
public class SimpleIconService extends DefaultIconService implements
		InitializingBean {

	private Map<String, String> properties = new HashMap<String, String>();

	private String prefix;

	/**
	 * Gets the prefix.
	 * 
	 * @return the prefix
	 */
	public String getPrefix() {
		return prefix;
	}

	/**
	 * Sets the resource path prefix.
	 * 
	 * @param prefix
	 *            the new prefix
	 */
	@Required
	public void setPrefix(String prefix) {
		this.prefix = prefix;
	}

	/**
	 * Gets the properties.
	 * 
	 * @return the properties
	 */
	public Map<String, String> getProperties() {
		return properties;
	}

	/**
	 * Sets the index of icon paths per icon id.
	 * 
	 * @param properties
	 *            the properties
	 */
	@Required
	public void setProperties(Map<String, String> properties) {
		this.properties = properties;
	}

	/**
	 * {@inheritDoc}
	 */
	public void afterPropertiesSet() throws Exception {
		for (Map.Entry<String, String> entry : properties.entrySet()) {
			String id = entry.getKey();
			String suffix = entry.getValue();
			IconDefinition definition = new IconDefinition(prefix, suffix,
					suffix, suffix, suffix, suffix);
			getIconDefinitions().put(id, definition);
		}
	}

}
