package net.sf.doolin.gui.spring;

import java.util.Collection;

import net.sf.doolin.context.spring.SimpleDefinitionParser;
import net.sf.doolin.gui.action.path.toolbar.ToolBar;
import net.sf.doolin.gui.window.descriptor.GUIWindowDescriptor;

import org.springframework.beans.PropertyValue;
import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.beans.factory.config.BeanDefinitionHolder;
import org.springframework.beans.factory.support.BeanDefinitionBuilder;
import org.springframework.beans.factory.support.ManagedList;
import org.springframework.beans.factory.xml.ParserContext;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

/**
 * Parser/decorator for a {@link ToolBar} in a {@link GUIWindowDescriptor}.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class ToolBarDecorator extends SimpleDefinitionParser<ToolBar> {

	/**
	 * Constructor.
	 */
	public ToolBarDecorator() {
		super(ToolBar.class);
		addSimpleAttribute("name");
		addSimpleAttribute("floatable");
		addSimpleAttribute("position");
		addCustomBeanAs("actionPathList", "actionPathList");
	}

	@Override
	public BeanDefinitionHolder decorate(Node node,
			BeanDefinitionHolder holder, ParserContext parserContext) {
		// Element
		Element element = (Element) node;
		// Parses this element
		ParserContext customParserContext = new ParserContext(parserContext
				.getReaderContext(), parserContext.getDelegate(), holder
				.getBeanDefinition());
		BeanDefinition definition = parse(element, customParserContext);
		// Gets the tool bar property
		@SuppressWarnings("unchecked")
		Collection<BeanDefinition> toolBars = (Collection<BeanDefinition>) holder
				.getBeanDefinition().getPropertyValues().getPropertyValue(
						"toolBars");
		// Adds the tool bar
		toolBars.add(definition);
		// OK
		return holder;
	}

	@Override
	@SuppressWarnings("unchecked")
	public void doParse(Element element, ParserContext parserContext,
			BeanDefinitionBuilder builder) {
		super.doParse(element, parserContext, builder);
		BeanDefinition containingBeanDefinition = parserContext
				.getContainingBeanDefinition();
		if (containingBeanDefinition != null) {
			// Gets the tool bar property
			PropertyValue propertyValue = containingBeanDefinition
					.getPropertyValues().getPropertyValue("toolBars");
			if (propertyValue == null) {
				propertyValue = new PropertyValue("toolBars", new ManagedList());
				containingBeanDefinition.getPropertyValues().addPropertyValue(
						propertyValue);
			}
			ManagedList toolBars = (ManagedList) propertyValue.getValue();
			// Adds the tool bar
			toolBars.add(builder.getBeanDefinition());
		}
	}

}
