package net.sf.doolin.gui.spring.table;

import net.sf.doolin.context.spring.SimpleBeanFactory;
import net.sf.doolin.context.spring.SimpleDefinitionParser;
import net.sf.doolin.gui.field.table.Column;
import net.sf.doolin.gui.field.table.column.ColumnAlwaysEditable;
import net.sf.doolin.gui.field.table.value.PropertyColumnValueFactory;

/**
 * Parser for {@link Column}.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class ColumnParser extends SimpleDefinitionParser<Column> {

	/**
	 * Constructor
	 */
	public ColumnParser() {
		super(Column.class);
		// Simple properties
		addSimpleAttribute("name");
		addSimpleAttribute("titleExpression");
		addSimpleAttribute("type");
		addSimpleAttribute("width");
		addSimpleAttribute("visible");
		addSimpleAttribute("required");
		addSimpleAttribute("columnUpdatePolicy");
		// propertyPath => PropertyColumnValueFactory
		addFactoryFromAttribute("propertyPath", "valueFactory",
				new SimpleBeanFactory() {

					@Override
					public Object create(String value) {
						PropertyColumnValueFactory factory = new PropertyColumnValueFactory();
						factory.setPropertyPath(value);
						return factory;
					}

				});
		// editable => ColumnAlwaysEditable if "true"
		addFactoryFromAttribute("editable", "editable",
				new SimpleBeanFactory() {

					@Override
					public Object create(String value) {
						if (Boolean.valueOf(value)) {
							return new ColumnAlwaysEditable<Object>();
						} else {
							return null;
						}
					}

				});
	}

}
