package net.sf.doolin.gui.style;

import java.awt.Color;
import java.awt.Component;

/**
 * Style that changes the background colour of the component.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class BackgroundStyle implements Style {

	private Color color;

	/**
	 * White colour
	 */
	public BackgroundStyle() {
		this(Color.white);
	}

	/**
	 * Constructor with a given colour
	 * 
	 * @param color
	 *            Colour to apply as background
	 */
	public BackgroundStyle(Color color) {
		this.color = color;
	}

	@Override
	public void apply(Component component) {
		component.setBackground(this.color);
	}

	/**
	 * Gets the colour to apply as background
	 * 
	 * @return Colour
	 */
	public Color getColor() {
		return this.color;
	}

	/**
	 * Sets the colour to apply as background
	 * 
	 * @param color
	 *            Colour
	 */
	public void setColor(Color color) {
		this.color = color;
	}

}
