package net.sf.doolin.gui.style;

import java.awt.Component;

import net.sf.doolin.util.Utils;

/**
 * 
 * Applies a style using a property of the target component.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class PropertyStyle implements Style {

	private String propertyName;
	private Object propertyValue;

	/**
	 * Constructor.
	 * 
	 * @param propertyName
	 *            Property to set on the component
	 * @param propertyValue
	 *            Property value to set on the component
	 */
	public PropertyStyle(String propertyName, Object propertyValue) {
		this.propertyName = propertyName;
		this.propertyValue = propertyValue;
	}

	/**
	 * Constructor with no property
	 */
	public PropertyStyle() {
	}

	@Override
	public void apply(Component component) {
		Utils.setProperty(component, this.propertyName, this.propertyValue);
	}

	/**
	 * Gets the property name
	 * 
	 * @return Property name
	 */
	public String getPropertyName() {
		return this.propertyName;
	}

	/**
	 * Sets the property name
	 * 
	 * @param propertyName
	 *            Property name
	 */
	public void setPropertyName(String propertyName) {
		this.propertyName = propertyName;
	}

	/**
	 * Gets the property value
	 * 
	 * @return Property value
	 */
	public Object getPropertyValue() {
		return this.propertyValue;
	}

	/**
	 * Sets the property value
	 * 
	 * @param propertyValue
	 *            Property value
	 */
	public void setPropertyValue(Object propertyValue) {
		this.propertyValue = propertyValue;
	}

}
