package net.sf.doolin.gui.swing;

import java.text.Format;
import java.util.List;

import javax.swing.JComboBox;

import org.apache.commons.lang.ObjectUtils;

import ca.odell.glazedlists.TextFilterator;
import ca.odell.glazedlists.matchers.TextMatcherEditor;

/**
 * Support class for the auto-completion of {@link JComboBox}.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <E>
 *            Type of item in the combo box
 */
public class CompletionSupport<E> {

	private Format format;
	private boolean strict;
	private String filterMode;
	private TextFilterator<E> textFilterator;

	/**
	 * Gets the format used for items
	 * 
	 * @return Format
	 */
	public Format getFormat() {
		return this.format;
	}

	/**
	 * Sets the format used for item
	 * 
	 * @param format
	 *            Format
	 */
	public void setFormat(Format format) {
		this.format = format;
	}

	/**
	 * Checks if the auto-completion does not accept new entries
	 * 
	 * @return <code>true</code> if the auto-completion does not accept new
	 *         entries
	 */
	public boolean isStrict() {
		return this.strict;
	}

	/**
	 * Sets if the auto-completion does not accept new entries
	 * 
	 * @param strict
	 *            <code>true</code> if the auto-completion does not accept new
	 *            entries
	 */
	public void setStrict(boolean strict) {
		this.strict = strict;
	}

	/**
	 * Gets the filter mode as defined as constants in {@link TextMatcherEditor}
	 * .
	 * 
	 * @return Filter mode
	 */
	public String getFilterMode() {
		return this.filterMode;
	}

	/**
	 * Sets the filter mode as defined as constants in {@link TextMatcherEditor}
	 * 
	 * @param filterMode
	 *            Filter mode
	 */
	public void setFilterMode(String filterMode) {
		this.filterMode = filterMode;
	}

	/**
	 * Gets the filter used by the combo box to convert items to text
	 * 
	 * @return Filter
	 */
	public TextFilterator<E> getTextFilterator() {
		return this.textFilterator;
	}

	/**
	 * Sets the filter used by the combo box to convert items to text
	 * 
	 * @param textFilterator
	 *            Filter
	 */
	public void setTextFilterator(TextFilterator<E> textFilterator) {
		this.textFilterator = textFilterator;
	}

	/**
	 * Returns the filter used by the combo box to convert items to text and
	 * creates it if needed
	 * 
	 * @return Filter
	 */
	public TextFilterator<E> getOrCreateTextFilterator() {
		if (this.textFilterator != null) {
			return this.textFilterator;
		} else {
			this.textFilterator = new TextFilterator<E>() {

				@Override
				public void getFilterStrings(List<String> baseList, E item) {
					baseList.add(ObjectUtils.toString(item, ""));
				}

			};
			return this.textFilterator;
		}
	}
}
