package net.sf.doolin.gui.swing;

import javax.swing.Icon;

import net.sf.doolin.gui.service.IconService;
import net.sf.doolin.gui.service.IconSize;
import net.sf.doolin.util.Utils;

import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Required;

/**
 * Creates a {@link LabelInfo} according to some properties in the item.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class PropertyLabelInfoProvider implements LabelInfoProvider {

	private String textPropertyPath;
	private String iconPropertyPath;

	private IconService iconService;

	@Override
	public LabelInfo getLabelIcon(Object item) {
		// No bean
		if (item == null) {
			return new LabelInfo(" ");
		}
		// Gets the text
		String text = ObjectUtils.toString(Utils.getProperty(item,
				this.textPropertyPath), "");
		// Gets the icon
		Icon icon = null;
		if (StringUtils.isNotBlank(this.iconPropertyPath)) {
			String iconKey = ObjectUtils.toString(Utils.getProperty(item,
					this.iconPropertyPath), null);
			if (iconKey != null) {
				icon = this.iconService.getIcon(iconKey, IconSize.SMALL);
			}
		}
		// OK
		return new LabelInfo(text, icon);
	}

	/**
	 * Sets the path to the property that contains the text
	 * 
	 * @param textPropertyPath
	 *            Path to the property that contains the text
	 */
	@Required
	public void setTextPropertyPath(String textPropertyPath) {
		this.textPropertyPath = textPropertyPath;
	}

	/**
	 * Sets the path to the property that contains the icon
	 * 
	 * @param iconPropertyPath
	 *            Property path
	 */
	public void setIconPropertyPath(String iconPropertyPath) {
		this.iconPropertyPath = iconPropertyPath;
	}

	/**
	 * Sets the icon service used to access the icon
	 * 
	 * @param iconService
	 *            Icon service
	 */
	@Autowired
	public void setIconService(IconService iconService) {
		this.iconService = iconService;
	}

}
