/*
 * Created on Jul 17, 2007
 */
package net.sf.doolin.gui.util;

import net.sf.jstring.JStrings;

import java.util.Locale;

/**
 * Service for localized strings.
 * 
 * @author Damien Coraboeuf
 */
public class GUIStrings {

	private GUIStrings() {
	}

	/**
	 * Gets a localized string.
	 * 
	 * @param code
	 *            String code
	 * @param params
	 *            String parameters
	 * @return Localized string
	 * @see JStrings#get(Locale, String, Object...)
	 */
	public static String get(Object code, Object... params) {
		return JStrings.get(getLocale(), code, params);
	}

	/**
	 * Gets a string from its code if defined, or returns <code>null</code> if
	 * it is not defined
	 * 
	 * @param code
	 *            String code
	 * @return String or <code>null</code> if the string code is not defined
	 * @see JStrings#get(Locale, String, boolean)
	 */
	public static String getIfPresent(String code) {
		return JStrings.get(getLocale(), code, false);
	}

	/**
	 * Gets the current locale
	 * 
	 * @return Locale
	 * @see Locale#getDefault()
	 */
	public static Locale getLocale() {
		return Locale.getDefault();
	}

	/**
	 * Checks if a string code is defined in the available bundles
	 * 
	 * @param key
	 *            String code
	 * @return <code>true</code> if the string code is defined
	 * @see JStrings#isDefined(Locale, String)
	 */
	public static boolean isDefined(String key) {
		return JStrings.isDefined(getLocale(), key);
	}

}
