package net.sf.doolin.gui.util;

import net.sf.doolin.gui.app.GUIApplication;
import net.sf.doolin.gui.service.GUIPreferences;
import net.sf.doolin.gui.service.Memento;
import net.sf.doolin.util.factory.DataFactory;

import org.springframework.beans.factory.annotation.Autowired;

/**
 * Data factory that reads its created object from the preferences after having
 * instantiating it using another factory.
 * 
 * @author Damien Coraboeuf
 * @param <T>
 *            Type of the object to read
 * 
 */
public class PreferencesDataFactory<T extends Memento> implements
		DataFactory<T> {

	@Autowired
	private GUIApplication application;
	private final DataFactory<T> initialFactory;

	/**
	 * Constructor
	 * 
	 * @param initialFactory
	 *            Factory to create the initial object
	 */
	public PreferencesDataFactory(DataFactory<T> initialFactory) {
		this.initialFactory = initialFactory;
	}

	@Override
	public T create(Object context) {
		// Creates the instance
		T o = this.initialFactory.create(context);
		// Gets the preferences
		GUIPreferences preferences = this.application.getPreferences();
		// Reads the instance from the preferences
		preferences.restoreMemento(o);
		// OK
		return o;
	}

}
