package net.sf.doolin.gui.validation;

import java.util.Map;

import net.sf.doolin.bus.SubscriberValidator;

/**
 * Defines the support for the validation of a view
 * 
 * @author Damien Coraboeuf
 * 
 * @param <B>
 *            Type of object for the view
 */
public interface ValidationSupport<B> {

	/**
	 * Checks if is validation enabled.
	 * 
	 * @return true, if is validation enabled
	 */
	boolean isValidationEnabled();

	/**
	 * Gets the result of the validation
	 * 
	 * @return Validation result
	 */
	GUIValidation getValidation();

	/**
	 * Checks if the validation is OK
	 * 
	 * @return <code>true</code> if validation is OK
	 */
	boolean isValid();

	/**
	 * Sets the validator to use for this validation support.
	 * 
	 * @param newValidator
	 *            Validator to use
	 */
	void setValidator(GUIValidator<B> newValidator);

	/**
	 * Index of validation results, indexed by field keys
	 * 
	 * @return Index of validation results, indexed by field keys
	 */
	Map<Object, GUIValidation> keyMap();

	/**
	 * Sets the validation as being invalid (used for Cancel actions)
	 */
	void invalidate();

	/**
	 * Gets the subscription validator that is used.
	 * 
	 * @return Subscription validator
	 */
	SubscriberValidator getSubscriberValidator();

}
