package net.sf.doolin.gui.view.support;

import javax.swing.JComponent;

import net.sf.doolin.bus.SubscriberValidator;
import net.sf.doolin.bus.support.PropertyChangeSupport;
import net.sf.doolin.gui.action.support.AbstractActionContext;
import net.sf.doolin.gui.app.GUIApplication;
import net.sf.doolin.gui.validation.ValidationSupport;
import net.sf.doolin.gui.view.GUIView;
import net.sf.doolin.gui.window.GUIWindow;

/**
 * Context based on a view.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <V>
 *            Type of object for the view
 */
public class ViewActionContext<V> extends AbstractActionContext {

	private static final long serialVersionUID = 1L;

	private final GUIView<V> view;
	private ViewSubscriberValidator<V> subscriberValidator;

	/**
	 * Constructor
	 * 
	 * @param view
	 *            View
	 */
	public ViewActionContext(GUIView<V> view) {
		super();
		this.view = view;
		this.subscriberValidator = new ViewSubscriberValidator<V>(this.view);
	}

	/**
	 * Constructor
	 * 
	 * @param view
	 *            View
	 * @param initialContextValue
	 *            Initial context value
	 */
	public ViewActionContext(GUIView<V> view, Object initialContextValue) {
		super(initialContextValue);
		this.view = view;
		this.subscriberValidator = new ViewSubscriberValidator<V>(this.view);
	}

	@Override
	protected <T> ValidationSupport<T> createValidationSupport() {
		ValidationSupport<T> validationSupport = super
				.createValidationSupport();
		// Listens to validation changes
		PropertyChangeSupport.subscribe(this.subscriberValidator,
				validationSupport, "validation", new Runnable() {

					@Override
					public void run() {
						// Notifies the window that a child view validation has
						// changed
						GUIWindow<?> window = ViewActionContext.this.view
								.getParentWindow();
						if (window != null) {
							ValidationSupport<Object> windowValidationSupport = window
									.getActionContext().getValidationSupport();
							PropertyChangeSupport.change(
									windowValidationSupport, "validation",
									null, windowValidationSupport
											.getValidation());
						}
					}
				});
		// OK
		return validationSupport;
	}

	@Override
	public GUIApplication getApplication() {
		return getWindow().getApplication();
	}

	@Override
	public JComponent getComponent() {
		return this.view.getViewComponent();
	}

	@Override
	public Object getData() {
		return this.view.getViewData();
	}

	@Override
	public SubscriberValidator getSubscriberValidator() {
		return this.subscriberValidator;
	}

	@SuppressWarnings("unchecked")
	@Override
	public <T> GUIView<T> getView() {
		return (GUIView<T>) this.view;
	}

	@SuppressWarnings("unchecked")
	@Override
	public <T> GUIWindow<T> getWindow() {
		return (GUIWindow<T>) this.view.getParentWindow();
	}

}
