package net.sf.doolin.gui.view.support;

import net.sf.doolin.bus.SubscriberValidator;
import net.sf.doolin.gui.view.GUIView;

/**
 * {@link SubscriberValidator} that follows the life-cycle of a
 * {@linkplain GUIView view}.
 * <p>
 * The subscription is valid while:
 * <ul>
 * <li>The view is not closed</li>
 * <li><b>and</b> its parent window is not closed</li>
 * </ul>
 * 
 * @author Damien Coraboeuf
 * 
 * @param <V>
 *            Type of bean for the view
 */
public class ViewSubscriberValidator<V> implements SubscriberValidator {

	private final GUIView<V> view;

	/**
	 * Constructor
	 * 
	 * @param view
	 *            View
	 */
	public ViewSubscriberValidator(GUIView<V> view) {
		this.view = view;
	}

	@Override
	public String getValidatorDescription() {
		return "View " + this.view.getID();
	}

	@Override
	public boolean isValid() {
		return !this.view.isClosed() && !this.view.getParentWindow().isClosed();
	}

}
