package net.sf.doolin.gui.window.support;

import net.sf.doolin.gui.window.GUIWindow;
import net.sf.doolin.gui.window.GUIWindowFactory;
import net.sf.doolin.gui.window.dialog.DefaultDialogActionsFactory;
import net.sf.doolin.gui.window.dialog.DialogActionsFactory;
import net.sf.doolin.gui.window.dialog.DialogGUIWindow;

/**
 * {@link GUIWindowFactory} for a dialog.
 * 
 * @author Damien Coraboeuf
 * @see DialogGUIWindow
 * 
 */
public class DialogWindowFactory implements GUIWindowFactory {

	@SuppressWarnings("unchecked")
	private DialogActionsFactory dialogActionsFactory = new DefaultDialogActionsFactory();

	@Override
	public <B> GUIWindow<B> createWindow() {
		return new DialogGUIWindow<B>(this.dialogActionsFactory);
	}

	/**
	 * Gets the dialog actions factory (for OK and Cancel)
	 * 
	 * @return Dialog actions factory
	 */
	public DialogActionsFactory getDialogActionsFactory() {
		return this.dialogActionsFactory;
	}

	/**
	 * Sets the dialog actions factory (for OK and Cancel). It is set by default
	 * to {@link DefaultDialogActionsFactory}.
	 * 
	 * @param dialogActionsFactory
	 *            Dialog actions factory
	 */
	public void setDialogActionsFactory(
			DialogActionsFactory dialogActionsFactory) {
		this.dialogActionsFactory = dialogActionsFactory;
	}

}
