/**
 * 
 */
package net.sf.doolin.gui.window.support;

import java.util.Collection;

import net.sf.doolin.gui.validation.ValidationSupport;
import net.sf.doolin.gui.validation.support.ValidationSupportImpl;
import net.sf.doolin.gui.view.GUIView;

/**
 * Implementation for the validation support for a window.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <T>
 *            Type of bean for the window
 */
public final class WindowValidationSupportImpl<T> extends
		ValidationSupportImpl<T> {

	private static final long serialVersionUID = 1L;

	private WindowActionContext<T> windowActionContext;

	/**
	 * Constructor
	 * 
	 * @param windowActionContext
	 *            Action context the validation support acts for
	 */
	@SuppressWarnings("unchecked")
	public WindowValidationSupportImpl(
			WindowActionContext<T> windowActionContext) {
		super((T) windowActionContext.getData(), windowActionContext
				.getSubscriberValidator());
		this.windowActionContext = windowActionContext;
	}

	/**
	 * Validation support for a window is valid if its support is valid
	 * <i>and</i> all views have a valid validation support.
	 */
	@Override
	public boolean isValid() {
		if (super.isValid()) {
			// Tests all views
			Collection<? extends GUIView<?>> views = this.windowActionContext
					.getWindow().getOpenViews();
			for (GUIView<?> view : views) {
				ValidationSupport<Object> viewValidationSupport = view
						.getActionContext().getValidationSupport();
				boolean validView = viewValidationSupport.isValid();
				if (!validView) {
					return false;
				}
			}
			// All views are valid
			return true;
		} else {
			return false;
		}
	}
}