package net.sf.doolin.gui.wizard.state;

import net.sf.doolin.bus.support.PropertyChangeSupport;
import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.display.AbstractDisplayStateHandler;
import net.sf.doolin.gui.display.DisplayState;
import net.sf.doolin.gui.display.DisplayStateHandler;

/**
 * {@link DisplayStateHandler} for a wizard action.
 * 
 * @author Damien Coraboeuf
 * 
 */
public abstract class AbstractWizardDisplayStateHandler extends
		AbstractDisplayStateHandler {

	@Override
	public DisplayState getDisplayState(ActionContext actionContext) {
		WizardState<?> state = (WizardState<?>) actionContext.getContext();
		return getDisplayState(state, actionContext);
	}

	@Override
	public void subscribe(ActionContext actionContext, Runnable task) {
		WizardState<?> state = (WizardState<?>) actionContext.getContext();
		PropertyChangeSupport.subscribe(actionContext.getSubscriberValidator(),
				state, null, task);
		PropertyChangeSupport.subscribe(actionContext.getSubscriberValidator(),
				state.getWizardModel(), null, task);
	}

	/**
	 * Gets the {@link DisplayState} according to the current
	 * {@link WizardState} and the action context.
	 * 
	 * @param <B>
	 *            Type of bean for the wizard
	 * @param state
	 *            Current wizard state
	 * @param actionContext
	 *            Wizard action context
	 * @return Display state
	 */
	protected abstract <B> DisplayState getDisplayState(WizardState<B> state,
			ActionContext actionContext);
}
