package net.sf.doolin.gui.wizard.support;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.display.AndDisplayStateHandler;
import net.sf.doolin.gui.display.DisplayStateHandler;
import net.sf.doolin.gui.display.ValidationDisplayStateHandler;
import net.sf.doolin.gui.wizard.state.FinishDisplayStateHandler;

/**
 * "Finish" action.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class WizardFinishAction extends AbstractWizardAction {

	/**
	 * Constructor.
	 */
	public WizardFinishAction() {
		this("Wizard.action.finish");
	}

	/**
	 * Constructor with custom text
	 * 
	 * @param text
	 *            Text for the button
	 */
	public WizardFinishAction(String text) {
		this(text, new FinishDisplayStateHandler());
	}

	/**
	 * Constructor with custom text and display state handler. The handler will
	 * be associated with a {@link ValidationDisplayStateHandler}.
	 * 
	 * @param text
	 *            Text for the button
	 * @param handler
	 *            Display state handler
	 */
	public WizardFinishAction(String text, DisplayStateHandler handler) {
		super(WizardAction.FINISH, text);
		setDisplayStateHandler(new AndDisplayStateHandler(
				new ValidationDisplayStateHandler(), handler));
	}

	/**
	 * Just {@linkplain WizardWindow#close() closes} the wizard.
	 */
	@Override
	protected void doExecute(ActionContext context) throws Exception {
		getWizard(context).close();
	}

	@Override
	protected String getShortcut() {
		return null;
	}

}
