package net.sf.doolin.gui.wizard.support;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.display.DisplayStateHandler;
import net.sf.doolin.gui.wizard.state.PreviousDisplayStateHandler;
import net.sf.doolin.gui.wizard.state.WizardState;

/**
 * "Previous" action for the wizard.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class WizardPreviousAction extends AbstractWizardAction {

	/**
	 * Constructor.
	 */
	public WizardPreviousAction() {
		this("Wizard.action.previous");
	}

	/**
	 * Constructor with custom text and a default
	 * {@link PreviousDisplayStateHandler} display state handler.
	 * 
	 * @param text
	 *            Text for the button
	 */
	public WizardPreviousAction(String text) {
		this(text, new PreviousDisplayStateHandler());
	}

	/**
	 * Constructor with custom text and a custom display state handler
	 * 
	 * @param text
	 *            Text for the button
	 * @param handler
	 *            Display state handler
	 */
	public WizardPreviousAction(String text, DisplayStateHandler handler) {
		super(WizardAction.PREVIOUS, text);
		setDisplayStateHandler(handler);
	}

	/**
	 * Gets the {@link WizardState} from the context and calls its
	 * {@link WizardState#doPrevious(ActionContext)} method.
	 */
	@Override
	protected void doExecute(ActionContext context) throws Exception {
		WizardState<?> state = (WizardState<?>) context.getContext();
		state.doPrevious(context);
	}

	@Override
	protected String getShortcut() {
		return "ctrl KP_LEFT";
	}

}
