package net.sf.doolin.gui.docking;

import net.sf.doolin.util.Utils;

import com.javadocking.dock.BorderDock;
import com.javadocking.dock.Dock;
import com.javadocking.dock.FloatDock;
import com.javadocking.dock.LineDock;
import com.javadocking.dock.SingleDock;
import com.javadocking.dock.SplitDock;

/**
 * List of docks that can be created.
 * 
 * @author Damien Coraboeuf
 * 
 */
public enum DockType {

	/**
	 * @see SplitDock
	 */
	SPLIT(SplitDock.class),
	/**
	 * @see BorderDock
	 */
	BORDER(BorderDock.class),
	/**
	 * @see LineDock
	 */
	LINE(LineDock.class),
	/**
	 * @see SingleDock
	 */
	SINGLE(SingleDock.class),
	/**
	 * @see FloatDock
	 */
	FLOAT(FloatDock.class);

	/**
	 * Gets the dock type from the class
	 * 
	 * @param dock
	 *            Dock
	 * @return Dock type
	 */
	public static DockType getDockType(Dock dock) {
		Class<? extends Dock> dockClass = dock.getClass();
		for (DockType type : values()) {
			if (type.dockClass.isAssignableFrom(dockClass)) {
				return type;
			}
		}
		throw new IllegalArgumentException(String.format(
				"Cannot find any dock type for class %s", dockClass.getName()));
	}

	private final Class<? extends Dock> dockClass;

	private DockType(Class<? extends Dock> dockClass) {
		this.dockClass = dockClass;
	}

	/**
	 * Creates a dock.
	 * 
	 * @return New dock.
	 */
	public Dock createDock() {
		return Utils.newInstance(this.dockClass);
	}

}
