package net.sf.doolin.gui.docking;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang.ArrayUtils;

import com.javadocking.dockable.DockableState;

/**
 * Specification for the constraints of a view in a
 * {@link DockingWindowDescriptor}.
 */
// TODO Use moveable flag
public class DockingConstraint {

	private boolean closeable;
	private boolean zoomable;
	private boolean moveable = true;
	private boolean header = true;
	private boolean externalizable;

	private String dockingPath;

	/**
	 * Returns the list of actions that are available for the view (all actions
	 * but closed can be defined this way).
	 * 
	 * @return List of actions
	 */
	public int[] getActions() {
		List<Integer> actions = new ArrayList<Integer>();
		actions.add(DockableState.NORMAL);
		if (this.zoomable) {
			actions.add(DockableState.MAXIMIZED);
			actions.add(DockableState.MINIMIZED);
		}
		if (this.externalizable) {
			actions.add(DockableState.EXTERNALIZED);
		}
		Integer[] t = actions.toArray(new Integer[actions.size()]);
		return ArrayUtils.toPrimitive(t);
	}

	/**
	 * Gets the docking path
	 * 
	 * @return Docking path
	 */
	public String getDockingPath() {
		return this.dockingPath;
	}

	/**
	 * Checks if he view can be closed
	 * 
	 * @return true if the view can be closed
	 */
	public boolean isCloseable() {
		return this.closeable;
	}

	/**
	 * Checks if the view can be externalized from its dock.
	 * 
	 * @return Externalizable state
	 */
	public boolean isExternalizable() {
		return this.externalizable;
	}

	/**
	 * Checks if the dock that contains the view must have a header
	 * 
	 * @return <code>true</code> if the dock that contains the view must have a
	 *         header
	 */
	public boolean isHeader() {
		return this.header;
	}

	/**
	 * Checks if the view can be moved from its dock
	 * 
	 * @return true if the view can be moved from its dock
	 */
	public boolean isMoveable() {
		return this.moveable;
	}

	/**
	 * Checks if the view can be zoomed
	 * 
	 * @return true if the view can be zoomed
	 */
	public boolean isZoomable() {
		return this.zoomable;
	}

	/**
	 * Sets if the view can be closed
	 * 
	 * @param closeable
	 *            true if the view can be closed
	 */
	public void setCloseable(boolean closeable) {
		this.closeable = closeable;
	}

	/**
	 * Path to the dock that must contain the view
	 * 
	 * @param dockingPath
	 *            Docking path
	 */
	public void setDockingPath(String dockingPath) {
		this.dockingPath = dockingPath;
	}

	/**
	 * Defines if the view can be externalized from its dock.
	 * 
	 * @param externalizable
	 *            Externalizable state
	 */
	public void setExternalizable(boolean externalizable) {
		this.externalizable = externalizable;
	}

	/**
	 * Sets if the dock must have a header when docked alone
	 * 
	 * @param header
	 *            <code>true</code> if the dockable must have a header when
	 *            docked alone
	 */
	public void setHeader(boolean header) {
		this.header = header;
	}

	/**
	 * Sets if the view can be moved from its dock
	 * 
	 * @param moveable
	 *            Moveable state
	 */
	public void setMoveable(boolean moveable) {
		this.moveable = moveable;
	}

	/**
	 * Sets true if the view can be zoomed
	 * 
	 * @param zoomable
	 *            Zoomable state
	 */
	public void setZoomable(boolean zoomable) {
		this.zoomable = zoomable;
	}

	@Override
	public String toString() {
		return this.dockingPath;
	}

}
