package net.sf.doolin.gui.docking.storage;

import net.sf.doolin.gui.docking.DockDescription;
import net.sf.doolin.gui.service.GUIPreferences;
import net.sf.doolin.gui.util.PreferencesUtils;
import net.sf.doolin.gui.window.GUIWindow;

/**
 * Implementation of {@link DockingStorage} that stores window position as
 * properties in the {@linkplain GUIPreferences preferences}.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class DefaultDockingStorage implements DockingStorage {

	@Override
	public DockDescription retrieve(GUIWindow<?> window) {
		// Window ID
		String windowId = window.getId();
		// Preferences key
		String key = String.format("Docking.%s", windowId);
		// Preferences
		GUIPreferences preferences = window.getApplication().getPreferences();
		// Retrieval from preferences
		DockDescription dockDescription = PreferencesUtils.getObject(
				preferences, key);
		// OK
		return dockDescription;
	}

	@Override
	public void store(GUIWindow<?> window, DockDescription description) {
		// Gets the preferences
		GUIPreferences preferences = window.getApplication().getPreferences();
		// Window id
		String windowId = window.getId();
		// Saves in preferences
		PreferencesUtils.setObject(preferences, String.format("Docking.%s",
				windowId), description);
		// Saves the preferences
		preferences.save();
	}

}
