package net.sf.doolin.gui.docking.storage;

import java.awt.Dimension;
import java.util.ArrayList;
import java.util.List;

import net.sf.doolin.gui.docking.DockDescription;

/**
 * Bean used by the {@link XMLDockingStorage} when retrieving the
 * {@link DockDescription} from an XML template.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class OXMLDocking {

	private String className;
	private boolean leaf;
	private String position;
	private Dimension size;

	private final List<String> viewIds = new ArrayList<String>();

	private final List<OXMLDocking> descriptions = new ArrayList<OXMLDocking>();

	/**
	 * Converts this bean to a {@link DockDescription} instance
	 * 
	 * @return Result of the conversion
	 */
	public DockDescription convert() {
		DockDescription d = new DockDescription(this.className, this.leaf,
				this.position, this.size);
		d.getViewIds().addAll(this.viewIds);
		for (OXMLDocking o : this.descriptions) {
			DockDescription cd = o.convert();
			d.add(cd);
		}
		return d;
	}

	/**
	 * Gets the class name for the dock
	 * 
	 * @return Class name
	 */
	public String getClassName() {
		return this.className;
	}

	/**
	 * Gets the list of sub-docks
	 * 
	 * @return List of docking descriptions
	 */
	public List<OXMLDocking> getDescriptions() {
		return this.descriptions;
	}

	/**
	 * Gets the position of this dock
	 * 
	 * @return Position
	 */
	public String getPosition() {
		return this.position;
	}

	/**
	 * Gets the size of this dock
	 * 
	 * @return Size
	 */
	public Dimension getSize() {
		return this.size;
	}

	/**
	 * Gets the list of view IDs
	 * 
	 * @return List of view IDs
	 */
	public List<String> getViewIds() {
		return this.viewIds;
	}

	/**
	 * Checks if this dock is a leaf.
	 * 
	 * @return <code>true</code> if this dock is a leaf.
	 */
	public boolean isLeaf() {
		return this.leaf;
	}

	/**
	 * Sets the class name for this dock
	 * 
	 * @param className
	 *            Class name
	 */
	public void setClassName(String className) {
		this.className = className;
	}

	/**
	 * Sets if this dock is a leaf.
	 * 
	 * @param leaf
	 *            <code>true</code> if this dock is a leaf.
	 */
	public void setLeaf(boolean leaf) {
		this.leaf = leaf;
	}

	/**
	 * Sets the position of this dock
	 * 
	 * @param position
	 *            Position
	 */
	public void setPosition(String position) {
		this.position = position;
	}

	/**
	 * Sets the size of this dock
	 * 
	 * @param size
	 *            Size
	 */
	public void setSize(Dimension size) {
		this.size = size;
	}

}
